# -*- coding: utf-8 -*-
from . import fleet_vehicle_battery_maximum_charge
from . import fleet_vehicle_battery_size
from . import models_cs_car
from . import fleet_vehicle_state
from . import res_config_settings
from . import res_company



# -*- coding: utf-8 -*-
from odoo import models, fields, api


class cs_battery_size(models.Model):
    _name = 'fleet.vehicle.battery.size'
    _rec_name = "battery_size"

    _sql_constraints = [
        (
            'unique_battery_size',
            'unique(battery_size)',
            'Battery Size must be unique'
        ),
    ]

    battery_size = fields.Integer(
        string='Size',
        required=True,
        index=True
    )



# -*- coding: utf-8 -*-
from odoo import fields, api, models, _
from odoo.exceptions import UserError
import logging


class ResConfigSettings(models.TransientModel):
    _inherit = 'res.config.settings'
    
    sm_carsharing_structure_sommobilitat_analitic_group = fields.Many2one(
        'account.analytic.group',
        related='company_id.sm_carsharing_structure_sommobilitat_analitic_group',
        string=_("Fleet Analitic Account Main Group"),
        readonly=False,
    )
    sm_carsharing_structure_sommobilitat_analitic_parent = fields.Many2one(
        'account.analytic.account',
        related='company_id.sm_carsharing_structure_sommobilitat_analitic_parent',
        string=_("Fleet Analitic Account Main Parent"),
        readonly=False,
    )


# -*- coding: utf-8 -*-
{
    'name': "sm_carsharing_structure_sommobilitat",

    'summary': """
         Extra fields any enterprise would need to add to fleet vehicle""",

    'author': "Som Mobilitat",
    'website': "https://www.sommobilitat.coop",

    'category': '',
    'version': '12.0.0.0.10',

    # any module necessary for this one to work correctly
    'depends': [
        'base',
        'vertical_carsharing',
        'fleet',
        'sm_carsharing_structure',
        'account_loan',
        'analytic',
    ],

    # always loaded
    'data': [
        'security/ir.model.access.csv',
        'data/fleet_vehicle_state.xml',
        'data/fleet_vehicle_battery_sizes.xml',
        'data/fleet_vehicle_battery_maximum_charges.xml',
        'views/fleet_vehicle_state_view.xml',
        'views/fleet_vehicle_battery_size_view.xml',
        'views/fleet_vehicle_battery_maximum_charge.xml',
        'views/views_cs_car.xml',
        'views/views_res_config_settings.xml',
    ],
}
